@@ -1,9 +1,7 @@
-import os
-
 from django.conf import settings
 from django.core.files.storage import FileSystemStorage
 
-from controller.utils import is_installed
+from controller.utils.apps import is_installed
 
 
 FIRMWARE_BASE_IMAGE_STORAGE = getattr(settings, 'FIRMWARE_BASE_IMAGE_STORAGE', None)
