@@ -1,7 +1,6 @@
 from __future__ import absolute_import
 
 from django import forms
-from django.conf.urls import patterns, url
 from django.contrib import admin, messages
 from django.core.urlresolvers import reverse
 from django.db import models
@@ -9,24 +8,25 @@ from django.db.models import Q
 from django.utils.safestring import mark_safe
 
 from controller.admin import ChangeViewActions, ChangeListDefaultFilter
-from controller.admin.utils import (colored, admin_link, wrap_admin_view,
-    docstring_as_help_tip)
+from controller.admin.utils import colored, admin_link, docstring_as_help_tip
+from controller.core.exceptions import InvalidMgmtAddress
 from controller.models.utils import get_help_text
 from controller.utils.html import monospace_format
-from permissions.admin import PermissionModelAdmin, PermissionTabularInline
 from controller.utils.singletons.admin import SingletonModelAdmin
+from permissions.admin import PermissionModelAdmin, PermissionTabularInline
 from users.helpers import filter_group_queryset
 
 from .actions import request_cert, reboot_selected
 from .filters import MyNodesListFilter
 from .forms import DirectIfaceInlineFormSet
 from .models import Node, NodeProp, Server, DirectIface
+from .utils import get_mgmt_backend_class
 
 
 STATES_COLORS = {
     Node.DEBUG: 'darkorange',
     Node.FAILURE: 'red',
-    Node.SAFE: 'grey',
+    Node.SAFE: 'blue',
     Node.PRODUCTION: 'green',
 }
 
@@ -35,7 +35,9 @@ class NodePropInline(PermissionTabularInline):
     model = NodeProp
     extra = 0
     verbose_name_plural = mark_safe('Node properties %s' % docstring_as_help_tip(NodeProp))
-
+    
+    class Media:
+        js = ('nodes/js/collapsed_node_properties.js',)
 
 class DirectIfaceInline(PermissionTabularInline):
     model = DirectIface
@@ -44,33 +46,38 @@ class DirectIfaceInline(PermissionTabularInline):
 
 
 class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin):
-    class Media:
-        js = ("nodes/js/nodes-admin.js",)
-
     list_display = [
         'name', 'id', 'arch', 'display_set_state', admin_link('group'), 'num_ifaces'
     ]
     list_display_links = ['name', 'id']
     list_filter = [MyNodesListFilter, 'arch', 'set_state']
     default_changelist_filters = (('my_nodes', 'True'),)
-    search_fields = ['description', 'name']
+    search_fields = ['description', 'name', 'id']
     readonly_fields = ['boot_sn', 'display_cert']
     inlines = [DirectIfaceInline, NodePropInline]
+    weights = {
+        'inlines': {
+            NodePropInline: 2
+        }
+    }
     fieldsets = (
         (None, {
-            'fields': ('name', 'description', 'group', 'arch', 'set_state'),
+            'fields': ('name', 'description', 'group', 'set_state'),
         }),
         ('Advanced', {
             'classes': ('collapse',),
-            'fields': ('sliver_pub_ipv4', 'sliver_pub_ipv4_range', 'local_iface',
-                       'display_cert', 'priv_ipv4_prefix', 'sliver_mac_prefix',
-                       'sliver_pub_ipv6', 'boot_sn')
+            'fields': ('arch', 'sliver_pub_ipv4', 'sliver_pub_ipv4_range',
+                       'local_iface', 'display_cert', 'priv_ipv4_prefix',
+                       'sliver_mac_prefix', 'sliver_pub_ipv6', 'boot_sn')
         }),
     )
     actions = [request_cert, reboot_selected]
     change_view_actions = [reboot_selected, request_cert]
     change_form_template = "admin/controller/change_form.html"
     
+    class Media:
+        js = ("nodes/js/nodes-admin.js",)
+    
     def display_set_state(self, node):
         return colored('set_state', STATES_COLORS, verbose=True, bold=False)(node)
     display_set_state.short_description = 'Set state'
@@ -93,12 +100,16 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
     num_ifaces.short_description = 'Ifaces'
     num_ifaces.admin_order_field = 'direct_ifaces__count'
     
+    def lookup_allowed(self, key, value):
+        if key in ('slivers__slice',):
+            return True
+        return super(NodeAdmin, self).lookup_allowed(key, value)
+    
     def get_form(self, request, obj=None, *args, **kwargs):
         """ request.user as default node admin """
         form = super(NodeAdmin, self).get_form(request, obj=obj, *args, **kwargs)
         if 'group' in form.base_fields:
             # ronly forms doesn't have initial nor queryset
-            user = request.user
             is_admin = Q(users__roles__is_admin=True)
             is_technician = Q(users__roles__is_technician=True)
             query = Q( is_admin | is_technician )
@@ -114,6 +125,22 @@ class NodeAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin
         """ Annotate direct iface counter to allow ordering on change list """
         qs = super(NodeAdmin, self).queryset(request)
         qs = qs.annotate(models.Count('direct_ifaces', distinct=True))
+        # HACK for searching nodes by IP
+        search = request.GET.get('q', False)
+        if search:
+            for query in search.split(' '):
+                mgmt_backend = get_mgmt_backend_class()
+                try:
+                    node = mgmt_backend.reverse(query)
+                except InvalidMgmtAddress:
+                    pass
+                else:
+                    # Skip django admin filtering
+                    request.GET._mutable = True
+                    request.GET.pop('q')
+                    request.GET._mutable = False
+                    qs = qs.filter(id=node.id)
+                    break
         return qs
     
     def get_readonly_fields(self, request, obj=None):
