@@ -1,6 +1,5 @@
 from __future__ import absolute_import
 
-import datetime
 import json
 import time
 
@@ -13,7 +12,7 @@ from django.shortcuts import redirect, get_object_or_404
 from django.utils.safestring import mark_safe
 
 from controller.admin.utils import display_timesince, wrap_admin_view
-from controller.utils import is_installed
+from controller.utils.apps import is_installed
 from permissions.admin import PermissionModelAdmin
 
 from .models import Ping
