@@ -1,7 +1,6 @@
-from django.contrib import messages
 from django.contrib.admin import helpers
 from django.core.exceptions import PermissionDenied
-from django.db import router, transaction
+from django.db import transaction
 from django.shortcuts import redirect, get_object_or_404
 from django.template.response import TemplateResponse
 from django.utils.encoding import force_text
