@@ -1,21 +1,20 @@
 from __future__ import absolute_import
 
 from django import forms
-from django.conf.urls import patterns, url, include
-from django.contrib import admin, messages
+from django.conf.urls import patterns, url
+from django.contrib import admin
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.db.models import Q
 from django.http import HttpResponseRedirect
 from django.shortcuts import get_object_or_404
-from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
 
 from controller.admin import ChangeViewActions, ChangeListDefaultFilter
 from controller.admin.utils import (colored, admin_link, link, get_admin_link,
-    insertattr, action_to_view, get_modeladmin, wrap_admin_view, docstring_as_help_tip)
+    insertattr, get_modeladmin, wrap_admin_view, docstring_as_help_tip)
 from controller.admin.widgets import LinkedRelatedFieldWidgetWrapper
-from nodes.admin import NodeAdmin, STATES_COLORS
+from nodes.admin import NodeAdmin
 from nodes.models import Node
 from permissions.admin import PermissionModelAdmin, PermissionTabularInline
 from users.helpers import filter_group_queryset
@@ -44,13 +43,30 @@ def num_slivers(instance):
     url += '?my_slivers=False&%s=%s' % (instance._meta.module_name, instance.pk)
     return mark_safe('<a href="%s">%d</a>' % (url, num))
 num_slivers.short_description = 'Slivers'
-num_slivers.admin_order_field = 'sliver__count'
+num_slivers.admin_order_field = 'slivers__count'
+
+
+def computed_sliver_set_state(sliver):
+    sliver_state = sliver.set_state
+    state = sliver.effective_set_state
+    effective = state != sliver_state
+    color = STATE_COLORS.get(state, "black")
+    state = filter(lambda s: s[0] == state, Slice.STATES)[0][1]
+    title = ''
+    if effective:
+        title = 'Set state from slice, the sliver state is %s' % sliver_state
+        state += '*'
+    return mark_safe('<span style="color:%s;" title="%s">%s</span>' % (color, title, state))
+computed_sliver_set_state.short_description = 'Set state'
 
 
 class SliverPropInline(PermissionTabularInline):
     model = SliverProp
     extra = 0
     verbose_name_plural = mark_safe('Sliver properties %s' % docstring_as_help_tip(SliverProp))
+    
+    class Media:
+        js = ('slices/js/collapsed_properties.js',)
 
 
 class SliverIfaceInline(PermissionTabularInline):
@@ -77,21 +93,22 @@ class SliverIfaceInline(PermissionTabularInline):
 
 class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin):
     list_display = [
-        '__unicode__', admin_link('node'), admin_link('slice'), 'computed_set_state'
+        '__unicode__', admin_link('node'), admin_link('slice'), computed_sliver_set_state
     ]
     list_filter = [MySliversListFilter, SliverSetStateListFilter, 'slice__name']
     fieldsets = (
         (None, {
-            'fields': ('description', 'template', 'exp_data', 'set_state')
+            'fields': ('description', 'template', 'set_state')
         }),
         ('Advanced', {
             'classes': ('collapse',),
-            'fields': ('new_instance_sn', 'exp_data_sha256',)
+            'fields': ('exp_data', 'exp_data_sha256', 'overlay', 'overlay_sha256',
+                       'new_instance_sn')
         }),
     )
-    readonly_fields = ['new_instance_sn', 'exp_data_sha256']
-    search_fields = ['description', 'node__description', 'slice__name']
-    inlines = [SliverIfaceInline]
+    readonly_fields = ['new_instance_sn', 'exp_data_sha256', 'overlay_sha256']
+    search_fields = ['description', 'node__description', 'node__name', 'slice__name']
+    inlines = [SliverPropInline, SliverIfaceInline]
     actions = [update_selected]
     change_view_actions = [update_selected]
     default_changelist_filters = (('my_slivers', 'True'),)
@@ -124,13 +141,6 @@ class SliverAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdm
         return instance.slice.new_sliver_instance_sn
     new_instance_sn.short_description ='Instance sequence number'
     
-    def computed_set_state(self, sliver):
-        state = sliver.set_state if sliver.set_state else sliver.slice.set_state
-        color = STATE_COLORS.get(state, "black")
-        state = filter(lambda s: s[0] == state, Slice.STATES)[0][1]
-        return mark_safe('<span style="color:%s;">%s</spam>' % (color, state))
-    computed_set_state.short_description = 'Set state'
-    
     def has_add_permission(self, *args, **kwargs):
         """ 
         Removes add button on change list. Slivers can only be added from slice change form 
@@ -358,9 +368,10 @@ class SliverInline(PermissionTabularInline):
     """ Show slivers in read only fashion """
     model = Sliver
     max_num = 0
-    fields = ['sliver_link', 'node_link', 'cn_url']
+    fields = ['sliver_link', 'node_link', computed_sliver_set_state]
     readonly_fields = [
-        'sliver_link', 'node_link', 'cn_url', 'sliver_note1', 'sliver_note2'
+        'sliver_link', 'node_link', computed_sliver_set_state, 'sliver_note1',
+        'sliver_note2'
     ]
     
     class Media:
@@ -390,7 +401,6 @@ class SliverInline(PermissionTabularInline):
             self.verbose_name_plural = mark_safe(add_button)
         if not obj.slivers.exists():
             return [(None, {'fields': ['sliver_note2']})]
-    
         return super(SliverInline, self).get_fieldsets(request, obj=obj)
     
     def has_delete_permission(self, request, obj=None):
@@ -412,18 +422,30 @@ class SliverInline(PermissionTabularInline):
         """ Display node change link on the inline form """
         return get_admin_link(instance.node)
     node_link.short_description = 'Node'
+
+
+class SliverNodeInline(SliverInline):
+    fields = ['sliver_link', 'slice_link', computed_sliver_set_state]
+    readonly_fields = ['sliver_link', 'slice_link', computed_sliver_set_state]
     
-    def cn_url(self, instance):
-        """ Display CN url on the inline form """
-        node = instance.node
-        return mark_safe("<a href='%s'>%s</a>" % (node.cn_url, node.cn_url))
+    class Media:
+        js = ('slices/js/collapsed_sliver_inline.js',)
+    
+    def get_fieldsets(self, request, obj=None):
+        return super(SliverInline, self).get_fieldsets(request, obj=obj)
+    
+    def slice_link(self, instance):
+        return get_admin_link(instance.slice)
+    slice_link.short_description = 'Slice'
 
 
 class SlicePropInline(PermissionTabularInline):
     model = SliceProp
     extra = 0
-    verbose_name_plural = mark_safe('Slice Properties %s' % docstring_as_help_tip(SliceProp))
-
+    verbose_name_plural = mark_safe('Slice properties %s' % docstring_as_help_tip(SliceProp))
+    
+    class Media:
+        js = ('slices/js/collapsed_properties.js',)
 
 class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmin):
     list_display = [
@@ -433,21 +455,23 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
     list_display_links = ('name', 'id')
     list_filter = [MySlicesListFilter, 'set_state', 'template']
     readonly_fields = [
-        'instance_sn', 'new_sliver_instance_sn', 'expires_on', 'exp_data_sha256'
+        'instance_sn', 'new_sliver_instance_sn', 'expires_on', 'exp_data_sha256',
+        'overlay_sha256'
     ]
     date_hierarchy = 'expires_on'
     search_fields = ['name']
-    inlines = [SliverInline]
+    inlines = [SlicePropInline, SliverInline]
     actions = [reset_selected, renew_selected_slices]
     form = SliceAdminForm
     fieldsets = (
         (None, {
-            'fields': ('name', 'description', 'template', 'exp_data', 'set_state',
-                       'vlan_nr', 'expires_on', 'group'),
+            'fields': ('name', 'description', 'template', 'set_state','expires_on', 'group'),
         }),
         ('Advanced', {
             'classes': ('collapse',),
-            'fields': ('instance_sn', 'new_sliver_instance_sn', 'exp_data_sha256')
+            'fields': ('exp_data', 'exp_data_sha256', 'overlay', 'overlay_sha256',
+                       'vlan_nr', 'instance_sn', 'new_sliver_instance_sn',
+            )
         }),
     )
     change_form_template = "admin/slices/slice/change_form.html"
@@ -465,7 +489,6 @@ class SliceAdmin(ChangeViewActions, ChangeListDefaultFilter, PermissionModelAdmi
         """ Hook sliver management URLs on slice admin """
         urls = super(SliceAdmin, self).get_urls()
         admin_site = self.admin_site
-        opts = self.model._meta
         extra_urls = patterns("",
             url("^(?P<slice_id>\d+)/add_sliver/$",
                 wrap_admin_view(self, NodeListAdmin(Node, admin_site).changelist_view),
@@ -559,3 +582,4 @@ def queryset(request):
 node_modeladmin.queryset = queryset
 
 insertattr(Node, 'list_display', num_slivers)
+insertattr(Node, 'inlines', SliverNodeInline, weight=5)
