@@ -4,7 +4,7 @@ import ast
 
 from api import serializers, exceptions
 
-from .models import Slice, Sliver, Template, SliverIface
+from .models import Slice, Sliver, Template
 
 
 class IfaceField(serializers.WritableField):
@@ -35,7 +35,7 @@ class IfaceField(serializers.WritableField):
             model = getattr(parent.opts.model, self.source or 'interfaces').related.model
             try:
                 list_ifaces = ast.literal_eval(str(value))
-            except SyntaxError as e:
+            except SyntaxError:
                 raise exceptions.ParseError("Malformed Iface: %s" % str(value))
             if not related_manager:
                 # POST (new parent object
@@ -68,11 +68,14 @@ class SliverSerializer(serializers.UriHyperlinkedModelSerializer):
     exp_data_uri = serializers.HyperlinkedFileField(source='exp_data', required=False,
         read_only=True)
     exp_data_sha256 = serializers.Field()
+    overlay_uri = serializers.HyperlinkedFileField(source='overlay', required=False,
+        read_only=True)
+    overlay_sha256 = serializers.Field()
     instance_sn = serializers.IntegerField(read_only=True)
     
     class Meta:
         model = Sliver
-        exclude = ('exp_data',)
+        exclude = ('exp_data', 'overlay')
 
 
 class SliceSerializer(serializers.UriHyperlinkedModelSerializer):
@@ -83,13 +86,16 @@ class SliceSerializer(serializers.UriHyperlinkedModelSerializer):
     exp_data_uri = serializers.HyperlinkedFileField(source='exp_data', required=False,
         read_only=True)
     exp_data_sha256 = serializers.Field()
+    overlay_uri = serializers.HyperlinkedFileField(source='overlay', required=False,
+        read_only=True)
+    overlay_sha256 = serializers.Field()
     instance_sn = serializers.IntegerField(read_only=True)
     new_sliver_instance_sn = serializers.IntegerField(read_only=True)
     expires_on = serializers.DateTimeField(read_only=True)
     
     class Meta:
         model = Slice
-        exclude = ('exp_data',)
+        exclude = ('exp_data', 'overlay')
 
 
 class TemplateSerializer(serializers.UriHyperlinkedModelSerializer):
