@@ -1,4 +1,3 @@
-import os
 from datetime import timedelta
 
 from django.conf import settings
@@ -16,7 +15,6 @@ SLICES_TEMPLATE_TYPE_DFLT = getattr(settings, 'SLICES_TEMPLATE_TYPE_DFLT', 'debi
 
 SLICES_TEMPLATE_ARCHS = getattr(settings, 'SLICES_TEMPLATE_ARCHS', (
         ('amd64', 'amd64'),
-        ('ia64', 'ia64'),
         ('x86', 'x86'),
 ))
 
