@@ -1,11 +1,9 @@
 from django.contrib import messages
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import transaction
-from django.db.models import get_model
 from django.http import Http404
 from django.shortcuts import redirect
 
-from controller.admin.utils import get_modeladmin
 from controller.core.exceptions import OperationLocked
 
 from .tasks import get_state
@@ -19,8 +17,7 @@ def refresh(modeladmin, request, queryset):
     ids = queryset.values_list('object_id', flat=True)
     # Execute get_state isolated on a process to avoid gevent polluting the stack
     # and preventing this silly complain "gevent is only usable from a single thread"
-    # Don't know yet why ids has to be copied, otherwise task doesn't get monitored
-    # Maybe because somehow ids can not be properly serialized ?? WTF
+    # ids listqueryset is converted in a list in order to be properly serialized
     result = get_state.delay(module, ids=list(ids), lock=False)
     try:
         # Block until finish
@@ -43,10 +40,9 @@ def refresh_state(modeladmin, request, queryset):
     ids = queryset.values_list('pk', flat=True)
     # Execute get_state isolated on a process to avoid gevent polluting the stack
     # and preventing this silly complain "gevent is only usable from a single thread"
-    # Don't know yet why ids has to be copied, otherwise task doesn't get monitored
-    # Maybe because somehow ids can not be properly serialized ?? WTF
+    # ids listqueryset is converted in a list in order to be properly serialized
     try:
-        result = get_state.delay(module, ids=list(ids))
+        result = get_state.delay(module, ids=list(ids), lock=False)
         result.get()
     except OperationLocked:
         msg = 'This operation is currently being executed by another process'
@@ -62,7 +58,6 @@ def show_state(modeladmin, request, queryset):
         obj = queryset.get()
     except ObjectDoesNotExist:
         raise Http404
-    model_name = obj._meta.verbose_name_raw
     state = obj.state
     return redirect('admin:state_state_change', state.pk)
 show_state.url_name = 'state'
