@@ -2,19 +2,14 @@ from __future__ import absolute_import
 
 import datetime
 import json
-import re
-import time
 from dateutil.relativedelta import relativedelta
 
 from django.contrib import admin
-from django.contrib.admin.util import unquote
 from django.conf.urls import patterns, url
 from django.core.urlresolvers import reverse
-from django.db import IntegrityError
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 from django.utils import timezone
-from django.utils.encoding import force_text
 from django.utils.safestring import mark_safe
 from pygments import highlight
 from pygments.lexers import JsonLexer
@@ -22,45 +17,82 @@ from pygments.formatters import HtmlFormatter
 
 from controller.admin import ChangeViewActions
 from controller.admin.utils import (insertattr, get_admin_link, colored, get_modeladmin,
-    wrap_admin_view, display_timesince, display_timeuntil)
+        wrap_admin_view, display_timesince, display_timeuntil)
 from controller.models.utils import get_help_text
 from controller.utils.html import urlize
 from controller.utils.time import timesince
+from nodes.admin import STATES_COLORS as NODE_STATES_COLORS
 from nodes.models import Node
 from permissions.admin import PermissionModelAdmin
-from slices.admin import SliverInline, NodeListAdmin, SliceSliversAdmin, SliceAdmin
+from slices.admin import (SliverInline, SliverNodeInline, NodeListAdmin, SliceAdmin,
+        SliceSliversAdmin)
+from slices.admin import STATE_COLORS as SLIVER_STATES_COLORS
 from slices.helpers import wrap_action
-from slices.models import Sliver
+from slices.models import Sliver, Slice
 
 from .actions import refresh, refresh_state, show_state
-from .filters import NodeStateListFilter, SliverStateListFilter
+from .filters import NodeStateListFilter, SliverStateListFilter, FirmwareVersionListFilter
 from .helpers import break_headers, break_lines
 from .models import State, StateHistory, NodeSoftwareVersion
-from .settings import STATE_NODE_SOFT_VERSION_URL, STATE_NODE_SOFT_VERSION_NAME
+from .settings import (STATE_NODE_SOFT_VERSION_URL, STATE_NODE_SOFT_VERSION_NAME,
+        STATE_FLAPPING_CHANGES, STATE_FLAPPING_MINUTES)
 
 
-STATES_COLORS = {
-    'offline': 'red',
-    'crashed': 'red',
-    'debug': 'darkorange',
-    'safe': 'grey',
-    'production': 'green',
-    'failure': 'red',
-    'online': 'green',
-    'unknown': 'grey',
-    'registered': 'grey',
-    'deployed': 'darkorange',
-    'started': 'green',
+STATES_COLORS = dict(NODE_STATES_COLORS)
+STATES_COLORS.update({
+    State.OFFLINE: 'red',
+    State.CRASHED: 'red',
+    State.UNKNOWN: 'grey',
+    State.NODATA: 'purple',
+    'registered': SLIVER_STATES_COLORS[Slice.REGISTER],
+    'deployed': SLIVER_STATES_COLORS[Slice.DEPLOY],
+    'started': SLIVER_STATES_COLORS[Slice.START],
     'fail_alloc': 'red',
     'fail_deploy': 'red',
-    'fail_start': 'red'
-}
+    'fail_start': 'red',
+})
+
+
+def display_metadata(instance):
+    style = '<style>code,pre {font-size:1.13em;}</style><p></p>'
+    metadata = break_headers(instance.metadata)
+    metadata = highlight(metadata, JsonLexer(), HtmlFormatter())
+    return mark_safe(style + urlize(metadata))
+display_metadata.short_description = 'metadata'
+
+
+def display_data(instance):
+    style = '<style>code,pre {font-size:1.13em;}</style><p></p>'
+    data = break_lines(instance.data)
+    data = highlight(data, JsonLexer(), HtmlFormatter())
+    return mark_safe(style + urlize(data))
+display_data.short_description = 'data'
+
+
+def display_current(instance):
+    try:
+        title = json.loads(instance.data).get('errors', '')
+    except ValueError:
+        title = ''
+    else:
+        title = str(title)[2:-2].replace("u'", "'")
+    state = instance.current
+    color = STATES_COLORS.get(state, "black")
+    state = filter(lambda s: s[0] == instance.current, State.STATES)[0][1]
+    start = timezone.now()-datetime.timedelta(minutes=STATE_FLAPPING_MINUTES)
+    changes = instance.history.filter(start__gt=start).count()
+    if changes >= STATE_FLAPPING_CHANGES:
+        context = (changes, STATE_FLAPPING_MINUTES)
+        title += 'This state is flapping (%i/%imin)' % context
+        state += '*'
+    else:
+        state = '<b>%s</b>' % state
+    return '<span style="color:%s;" title="%s">%s</span>' % (color, title, state)
 
 
 class StateHistoryAdmin(admin.ModelAdmin):
     list_display = [
-        'state', colored('value', STATES_COLORS, verbose=True), 'display_start_date',
-        'display_end_date', 'duration'
+        'state', 'display_value', 'display_start_date', 'display_end_date', 'duration'
     ]
     list_display_links = ['state']
     actions = None
@@ -72,17 +104,22 @@ class StateHistoryAdmin(admin.ModelAdmin):
             return list_display[1:]
         return list_display
     
+    def display_value(self, instance):
+        value = colored('value', STATES_COLORS, verbose=True)(instance)
+        url = reverse('admin:state_history_data', args=[instance.pk])
+        return mark_safe('<a class="show-popup" href="#" url="%s">%s</a>' % (url, value))
+    
     def display_start_date(self, instance):
         time = instance.start.strftime('%b. %d, %Y, %I:%M %P')
         time_since = timesince(instance.start)
-        return mark_safe('<span title="%s">%s</span>' % (time_since, time))
+        return mark_safe('<span title="%s ago">%s</span>' % (time_since, time))
     display_start_date.admin_order_field = 'start'
     display_start_date.short_description = 'Started Date/time'
     
     def display_end_date(self, instance):
         time = instance.end.strftime('%b. %d, %Y, %I:%M %P')
         time_since = timesince(instance.end)
-        return mark_safe('<span title="%s">%s</span>' % (time_since, time))
+        return mark_safe('<span title="%s ago">%s</span>' % (time_since, time))
     display_end_date.admin_order_field = 'end'
     display_end_date.short_description = 'Ended Date/time'
     
@@ -129,6 +166,14 @@ class StateHistoryAdmin(admin.ModelAdmin):
     def has_add_permission(self, *args, **kwargs):
         return False
     
+    def data_view(self, request, object_id):
+        history = get_object_or_404(StateHistory, pk=object_id)
+        data = {
+            'metadata': display_metadata(history),
+            'data': display_data(history)
+        }
+        return HttpResponse(json.dumps(data), content_type="application/json")
+    
     def changes_view(self, request, object_id):
         state = get_object_or_404(State, pk=object_id)
         history = state.history
@@ -162,13 +207,14 @@ class StateHistoryAdmin(admin.ModelAdmin):
                 data.setdefault(state, []).append(duration[state])
                 current_states = current_states.union(set((state,)))
             for missing in distinct_states-current_states:
-                data.setdefault(state, []).append(0)
+                data.setdefault(missing, []).append(0)
         # Construct final data structure
         series = []
         for state in data:
             series.append({
                 'name': state,
                 'data': data[state],
+                'color': STATES_COLORS.get(state, None)
             })
         data = {
             'categories': list(monthly.keys()),
@@ -184,12 +230,12 @@ class StateAdmin(ChangeViewActions, PermissionModelAdmin):
                        'last_try', 'next_retry', 'last_change', 'current')
         }),
         ('Details', {
-            'fields': ('display_metadata', 'display_data')
+            'fields': (display_metadata, display_data)
         }),
     )
     readonly_fields = [
         'url_link', 'last_seen', 'last_try', 'next_retry', 'current', 'last_change',
-        'display_metadata', 'display_data', 'last_contact'
+        display_metadata, display_data, 'last_contact'
     ]
     change_view_actions = [refresh]
     change_form_template = 'admin/state/state/change_form.html'
@@ -204,6 +250,9 @@ class StateAdmin(ChangeViewActions, PermissionModelAdmin):
             url("^(?P<object_id>\d+)/history/changes/$",
                 wrap_admin_view(self, history_admin.changes_view),
                 name='state_history_changes'),
+            url("^(?P<object_id>\d+)/history/data/$",
+                wrap_admin_view(self, history_admin.data_view),
+                name='state_history_data'),
             url("^(?P<object_id>\d+)/history/$",
                 wrap_admin_view(self, history_admin.changelist_view),
                 name='state_history'),
@@ -232,31 +281,10 @@ class StateAdmin(ChangeViewActions, PermissionModelAdmin):
         return display_timeuntil(instance.next_retry_on)
     next_retry.help_text = 'Next time the state retrieval operation will be executed'
     
-    def display_metadata(self, instance):
-        style = '<style>code,pre {font-size:1.13em;}</style><br>'
-        metadata = break_headers(instance.metadata)
-        metadata = highlight(metadata, JsonLexer(), HtmlFormatter())
-        return mark_safe(style + urlize(metadata))
-    display_metadata.short_description = 'metadata'
-    
-    def display_data(self, instance):
-        style = '<style>code,pre {font-size:1.13em;}</style><br>'
-        # TODO render data according to header content-type
-        #      (when it becomes available in the node)
-        data = break_lines(instance.data)
-        data = highlight(data, JsonLexer(), HtmlFormatter())
-        return mark_safe(style + urlize(data))
-    display_data.short_description = 'data'
-    
     def current(self, instance):
-        state = colored('current', STATES_COLORS, verbose=True)(instance)
-        try:
-            errors = json.loads(instance.data).get('errors', '')
-        except ValueError:
-            errors = ''
-        else:
-            errors = str(errors)[2:-2].replace("u'", "'")
-        return mark_safe('<a href="history" title="%s">%s</a>' % (errors, state))
+        state = display_current(instance)
+        return mark_safe('<a href="history">%s</a>' % (state))
+    display_current.short_description = 'current'
     
     def has_add_permission(self, request):
         """ Object states can not be manually created """
@@ -298,11 +326,10 @@ def state_link(*args):
     if not obj.pk:
         # Don't know why state_link is ever called without a real object :(
         return
-    color = colored('current', STATES_COLORS, verbose=True)
     state = obj.state
-    model_name = obj._meta.verbose_name_raw
+    colored = display_current(state)
     url = reverse('admin:state_state_change', args=[state.pk])
-    return mark_safe('<a href="%s">%s</a>' % (url, color(state)))
+    return mark_safe('<a href="%s">%s</a>' % (url, colored))
 state_link.short_description = 'Current state'
 state_link.admin_order_field = 'state_set__value'
 
@@ -318,7 +345,7 @@ def firmware_version(node):
         url = STATE_NODE_SOFT_VERSION_URL(version)
         name = STATE_NODE_SOFT_VERSION_NAME(version)
         return mark_safe('<a href="%s">%s</a>' % (url, name))
-firmware_version.admin_order_field = 'soft_version'
+firmware_version.admin_order_field = 'soft_version__value'
 
 
 insertattr(Node, 'list_display', firmware_version)
@@ -331,11 +358,15 @@ insertattr(Node, 'actions', refresh_state)
 insertattr(Sliver, 'actions', refresh_state)
 insertattr(Node, 'list_filter', NodeStateListFilter)
 insertattr(Sliver, 'list_filter', SliverStateListFilter)
-insertattr(Node, 'list_filter', 'soft_version__value')
+insertattr(Node, 'list_filter', FirmwareVersionListFilter)
 SliverInline.sliver_state = state_link
 SliverInline.readonly_fields.append('sliver_state')
 SliverInline.fields.append('sliver_state')
 
+SliverNodeInline.sliver_state = state_link
+SliverNodeInline.readonly_fields.append('sliver_state')
+SliverNodeInline.fields.append('sliver_state')
+
 node_modeladmin = get_modeladmin(Node)
 node_modeladmin.set_change_view_action(show_state)
 sliver_modeladmin = get_modeladmin(Sliver)
