@@ -1,6 +1,7 @@
 from django.contrib import messages
 from django.contrib.admin import helpers
 from django.contrib.sites.models import RequestSite
+from django.core.exceptions import PermissionDenied
 from django.core.mail import send_mass_mail
 from django.db import transaction
 from django.template.response import TemplateResponse
@@ -38,6 +39,7 @@ def join_request(modeladmin, request, queryset):
             site = RequestSite(request)
             jrequest.send_creation_email(site)
             modeladmin.message_user(request, "Your join request has been sent (%s)" % group)
+            modeladmin.log_change(request, group, "Requested to join this group.")
 join_request.short_description = "Request to join the selected groups"
 join_request.url_name = 'join-request'
 
