@@ -1,6 +1,5 @@
 from django.conf import settings
 from django.contrib.auth import models as auth_models
-from django.core.exceptions import ObjectDoesNotExist
 from django.core.mail import send_mail
 from django.core import validators
 from django.db import models
@@ -130,7 +129,7 @@ class User(auth_models.AbstractBaseUser):
     The implementation is based on auth.models.AbstractBaseUser, more:
     https://docs.djangoproject.com/en/dev/topics/auth/#customizing-the-user-model
     """
-    username = models.CharField(max_length=30, unique=True,
+    username = models.CharField(max_length=30, unique=True, db_index=True,
             help_text='Required. 30 characters or fewer. Letters, numbers and '
                       '@/./+/-/_ characters',
             validators=[validators.RegexValidator('^[\w.@+-]+$', 
