@@ -140,7 +140,7 @@ INSTALLED_APPS = (
     'django_extensions',
     'djcelery',
     'djcelery_email',
-    'private_files',
+    'privatefiles',
     'registration',
     'captcha', 
     'django_google_maps',
@@ -151,6 +151,7 @@ INSTALLED_APPS = (
     'admin_tools.theming',
     'admin_tools.menu',
     'admin_tools.dashboard',
+    'django_orphaned',
     
     # Django.contrib
     'django.contrib.auth',
@@ -291,10 +292,9 @@ BROKER_CONNECTION_TIMEOUT = None
 #CELERYD_HIJACK_ROOT_LOGGER = False
 #CELERY_SEND_TASK_ERROR_EMAILS = True
 # Route state tasks to avoid gevent polluting other tasks
-# FIXME state.get_state ignores the queue!!!!
 CELERY_ROUTES = {
-         'state.nodestate': {'queue': 'gevent'},
-         'state.sliverstate': {'queue': 'gevent'},
+         'state.node': {'queue': 'gevent'},
+         'state.sliver': {'queue': 'gevent'},
          'state.get_state': {'queue': 'gevent'},
 },
 ## end
@@ -327,10 +327,59 @@ REST_FRAMEWORK = {
 
 USE_ETAGS = True
 
+
+LOGGING = {
+    'version': 1,
+    'disable_existing_loggers': True,
+    'formatters': {
+        'standard': {
+            'format' : "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
+            'datefmt' : "%d/%b/%Y %H:%M:%S"
+        },
+    },
+    'handlers': {
+        'null': {
+            'level':'DEBUG',
+            'class':'django.utils.log.NullHandler',
+        },
+        'logfile': {
+            'level':'DEBUG',
+            'class':'logging.handlers.RotatingFileHandler',
+            'filename': '/dev/null',
+            'maxBytes': 50000,
+            'backupCount': 2,
+            'formatter': 'standard',
+        },
+        'console':{
+            'level':'INFO',
+            'class':'logging.StreamHandler',
+            'formatter': 'standard'
+        },
+    },
+    'loggers': {
+        'django': {
+            'handlers':['console'],
+            'propagate': True,
+            'level':'WARN',
+        },
+        'django.db.backends': {
+            'handlers': ['console'],
+            'level': 'DEBUG',
+            'propagate': False,
+        },
+        'state.models': {
+#            'handlers': ['console', 'logfile'],
+            'handlers': ['console'],
+            'level': 'DEBUG',
+        },
+    }
+}
+
+
+
 ###################################
 ## CONTROLLER APPS CONFIGURATION ##
 ###################################
 
 # common.api
 CUSTOM_API_ROOT = 'controller.api.Base'
-
